@@ -5,8 +5,7 @@
 
 /*
  * Copyright (c) 2007-2008 Roy Marples <roy@marples.name>
- * All rights reserved
-
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
@@ -55,6 +54,54 @@ rc_yesno(const char *value)
 }
 librc_hidden_def(rc_yesno)
 
+
+/**
+ * Read the entire @file into the buffer and set @len to the
+ * size of the buffer when finished. For C strings, this will
+ * be strlen(buffer) + 1.
+ * Don't forget to free the buffer afterwards!
+ */
+bool
+rc_getfile(const char *file, char **buffer, size_t *len)
+{
+	bool ret = false;
+	FILE *fp;
+	int fd;
+	struct stat st;
+	size_t done, left;
+
+	fp = fopen(file, "re");
+	if (!fp)
+		return false;
+
+	/* assume fileno() never fails */
+	fd = fileno(fp);
+
+	if (fstat(fd, &st))
+		goto finished;
+
+	left = st.st_size;
+	*len = left + 1; /* NUL terminator */
+	*buffer = xrealloc(*buffer, *len);
+	while (left) {
+		done = fread(*buffer, sizeof(*buffer[0]), left, fp);
+		if (done == 0 && ferror(fp))
+			goto finished;
+		left -= done;
+	}
+	ret = true;
+
+ finished:
+	if (!ret) {
+		free(*buffer);
+		*len = 0;
+	} else
+		(*buffer)[*len - 1] = '\0';
+	fclose(fp);
+	return ret;
+}
+librc_hidden_def(rc_getfile)
+
 ssize_t
 rc_getline(char **line, size_t *len, FILE *fp)
 {
@@ -174,10 +221,8 @@ rc_config_load(const char *file)
 		/* In shells the last item takes precedence, so we need to remove
 		   any prior values we may already have */
 		TAILQ_FOREACH(cline, config, entries) {
-			p = strchr(cline->value, '=');
-			if (p && strncmp(entry, cline->value,
-				(size_t)(p - cline->value)) == 0)
-			{
+			i = strlen(entry);
+			if (strncmp(entry, cline->value, i) == 0 && cline->value[i] == '=') {
 				/* We have a match now - to save time we directly replace it */
 				free(cline->value);
 				cline->value = newline;
@@ -203,15 +248,13 @@ rc_config_value(RC_STRINGLIST *list, const char *entry)
 {
 	RC_STRING *line;
 	char *p;
-	size_t len, dif;
+	size_t len;
 
 	len = strlen(entry);
 	TAILQ_FOREACH(line, list, entries) {
 		p = strchr(line->value, '=');
 		if (p != NULL) {
-			dif = (p - line->value);
-			if (dif == len &&
-			    strncmp(entry, line->value, dif) == 0)
+			if (strncmp(entry, line->value, len) == 0 && line->value[len] == '=')
 				return ++p;
 		}
 	}
